import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:plotter/cubit/settings_global_cubit.dart';
import 'package:unicons/unicons.dart';

import 'package:plotter/ui/settings/theme_card.dart';

class SettingsForm extends StatefulWidget {
  const SettingsForm({super.key});

  @override
  State<SettingsForm> createState() => _SettingsFormState();
}

class _SettingsFormState extends State<SettingsForm> {
  final apiHostFieldController = TextEditingController();

  @override
  void didChangeDependencies() {
    GlobalSettingsCubit settings = BlocProvider.of<GlobalSettingsCubit>(context);

    apiHostFieldController.text = settings.getParameterValue('apiHost');

    super.didChangeDependencies();
  }

  @override
  void dispose() {
    apiHostFieldController.dispose();

    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    void saveSettings() {
      BlocProvider.of<GlobalSettingsCubit>(context).setValues(
        apiHost: apiHostFieldController.text,
      );
    }

    return Column(
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisSize: MainAxisSize.max,
      children: <Widget>[
        // Light/dark theme
        Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: <Widget>[
            const Text('settings_label_theme').tr(),
            const Row(
              mainAxisAlignment: MainAxisAlignment.end,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                ThemeCard(
                  mode: ThemeMode.system,
                  icon: UniconsLine.cog,
                ),
                ThemeCard(
                  mode: ThemeMode.light,
                  icon: UniconsLine.sun,
                ),
                ThemeCard(
                  mode: ThemeMode.dark,
                  icon: UniconsLine.moon,
                )
              ],
            ),
          ],
        ),
        const SizedBox(height: 16),

        // Api settings
        const Text('settings_label_api_host').tr(),
        TextFormField(
          controller: apiHostFieldController,
          decoration: InputDecoration(
            border: const UnderlineInputBorder(),
            suffixIcon: ElevatedButton(
              style: ElevatedButton.styleFrom(
                shape: RoundedRectangleBorder(
                  borderRadius: BorderRadius.circular(6.0),
                ),
              ),
              child: const Icon(UniconsLine.save),
              onPressed: () {
                saveSettings();
              },
            ),
          ),
        ),

        const SizedBox(height: 16),
      ],
    );
  }
}
